@@ -2,8 +2,8 @@ getSigmaI <- function(model, what="s", series=NULL, digits=NULL)
 {
   ## 1  Parse args
   what <- match.arg(what, c("c","s"))
-  x <- if(class(model)=="scape" && what=="c") model$CPUE
-       else if(class(model)=="scape" && what=="s") model$Survey
+  x <- if(inherits(model,"scape") && what=="c") model$CPUE
+       else if(inherits(model,"scape") && what=="s") model$Survey
        else model  # allow data frame
   if(is.null(x))
     stop(paste("element", if(what=="s") "'Survey'" else "'CPUE'", "not found"))
