@@ -1,7 +1,7 @@
 getSigmaR <- function(model, digits=NULL)
 {
   ## 1  Parse args
-  x <- if(class(model)=="scape") model$Dev else model  # allow data frame
+  x <- if(inherits(model,"scape")) model$Dev else model  # allow data frame
   if(is.null(x))
     stop("element 'Dev' not found")
 
