@@ -32,8 +32,8 @@ plotCA <- function(model, what="c", fit=TRUE, swap=FALSE, series=NULL, sex=NULL,
 
   ## 2  Parse args
   what <- match.arg(what, c("c","s"))
-  x <- if(class(model)=="scape" && what=="c") model$CAc
-       else if(class(model)=="scape" && what=="s") model$CAs
+  x <- if(inherits(model,"scape") && what=="c") model$CAc
+       else if(inherits(model,"scape") && what=="s") model$CAs
        else model  # allow data frame
   if(is.null(x))
     stop("element '", what, "' not found")
